"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var common = require("./image-cache-it.common");
var image_cache_it_common_1 = require("./image-cache-it.common");
var view_1 = require("@nativescript/core/ui/core/view");
var fs = require("@nativescript/core/file-system");
var types = require("@nativescript/core/utils/types");
var style_properties_1 = require("@nativescript/core/ui/styling/style-properties");
var app = require("@nativescript/core/application");
var platform = require("@nativescript/core/platform");
var image_source_1 = require("@nativescript/core/image-source");
var core_1 = require("@nativescript/core");
__export(require("./image-cache-it.common"));
var main_queue = dispatch_get_current_queue();
var filter_queue = dispatch_get_global_queue(21, 0);
var ImageCacheIt = (function (_super) {
    __extends(ImageCacheIt, _super);
    function ImageCacheIt() {
        var _this = _super.call(this) || this;
        _this.progress = 0;
        _this._imageSourceAffectsLayout = true;
        _this._priority = 0;
        _this._loadStarted = false;
        return _this;
    }
    ImageCacheIt.prototype.createNativeView = function () {
        this.uuid = NSUUID.UUID().UUIDString;
        if (!ImageCacheIt.hasModifier) {
            SDWebImageDownloader.sharedDownloader.requestModifier = SDWebImageDownloaderRequestModifier.requestModifierWithBlock(function (request) {
                if (request && request.URL && request.URL.uuid && ImageCacheIt.cacheHeaders.has(request.URL.uuid)) {
                    var cachedHeader = ImageCacheIt.cacheHeaders.get(request.URL.uuid);
                    if (cachedHeader.url === request.URL.absoluteString) {
                        var newRequest_1 = request.mutableCopy();
                        if (cachedHeader.headers) {
                            cachedHeader.headers.forEach((function (value, key) {
                                newRequest_1.addValueForHTTPHeaderField(value, key);
                            }));
                        }
                        return newRequest_1.copy();
                    }
                }
                return request;
            });
            ImageCacheIt.hasModifier = true;
        }
        var nativeView = SDAnimatedImageView.new();
        nativeView.contentMode = 1;
        nativeView.userInteractionEnabled = true;
        nativeView.clipsToBounds = true;
        var metalDevice = MTLCreateSystemDefaultDevice() || null;
        if (metalDevice) {
            this.ctx = CIContext.contextWithMTLDevice(metalDevice);
        }
        else {
            var context = EAGLContext.alloc().initWithAPI(2);
            if (context) {
                this.ctx = CIContext.contextWithEAGLContext(context);
            }
            else {
                this.ctx = new CIContext(null);
            }
        }
        return nativeView;
    };
    ImageCacheIt.prototype._setNativeClipToBounds = function () {
        this.nativeView.clipsToBounds = true;
    };
    ImageCacheIt.prototype.onMeasure = function (widthMeasureSpec, heightMeasureSpec) {
        var _a, _b, _c, _d, _e, _f;
        var width = view_1.layout.getMeasureSpecSize(widthMeasureSpec);
        var widthMode = view_1.layout.getMeasureSpecMode(widthMeasureSpec);
        var height = view_1.layout.getMeasureSpecSize(heightMeasureSpec);
        var heightMode = view_1.layout.getMeasureSpecMode(heightMeasureSpec);
        var nativeWidth = (_c = view_1.layout.toDevicePixels((_b = (_a = this.nativeView) === null || _a === void 0 ? void 0 : _a.image) === null || _b === void 0 ? void 0 : _b.size.width)) !== null && _c !== void 0 ? _c : 0;
        var nativeHeight = (_f = view_1.layout.toDevicePixels((_e = (_d = this.nativeView) === null || _d === void 0 ? void 0 : _d.image) === null || _e === void 0 ? void 0 : _e.size.height)) !== null && _f !== void 0 ? _f : 0;
        var measureWidth = Math.max(nativeWidth, this.effectiveMinWidth);
        var measureHeight = Math.max(nativeHeight, this.effectiveMinHeight);
        var finiteWidth = widthMode !== view_1.layout.UNSPECIFIED;
        var finiteHeight = heightMode !== view_1.layout.UNSPECIFIED;
        this._imageSourceAffectsLayout = widthMode !== view_1.layout.EXACTLY || heightMode !== view_1.layout.EXACTLY;
        if (nativeWidth !== 0 && nativeHeight !== 0 && (finiteWidth || finiteHeight)) {
            var scale = ImageCacheIt.computeScaleFactor(width, height, finiteWidth, finiteHeight, nativeWidth, nativeHeight, this.stretch);
            var resultW = Math.round(nativeWidth * scale.width);
            var resultH = Math.round(nativeHeight * scale.height);
            measureWidth = finiteWidth ? Math.min(resultW, width) : resultW;
            measureHeight = finiteHeight ? Math.min(resultH, height) : resultH;
            if (core_1.Trace.isEnabled()) {
                core_1.Trace.write('ImageCacheIt stretch: ' + this.stretch + ', nativeWidth: ' + nativeWidth + ', nativeHeight: ' + nativeHeight, core_1.Trace.categories.Layout);
            }
        }
        var widthAndState = ImageCacheIt.resolveSizeAndState(measureWidth, width, widthMode, 0);
        var heightAndState = ImageCacheIt.resolveSizeAndState(measureHeight, height, heightMode, 0);
        this.setMeasuredDimension(widthAndState, heightAndState);
    };
    ImageCacheIt.computeScaleFactor = function (measureWidth, measureHeight, widthIsFinite, heightIsFinite, nativeWidth, nativeHeight, imageStretch) {
        var scaleW = 1;
        var scaleH = 1;
        if ((imageStretch === 'aspectFill' || imageStretch === 'aspectFit' || imageStretch === 'fill') && (widthIsFinite || heightIsFinite)) {
            scaleW = nativeWidth > 0 ? measureWidth / nativeWidth : 0;
            scaleH = nativeHeight > 0 ? measureHeight / nativeHeight : 0;
            if (!widthIsFinite) {
                scaleW = scaleH;
            }
            else if (!heightIsFinite) {
                scaleH = scaleW;
            }
            else {
                switch (imageStretch) {
                    case 'aspectFit':
                        scaleH = scaleW < scaleH ? scaleW : scaleH;
                        scaleW = scaleH;
                        break;
                    case 'aspectFill':
                        scaleH = scaleW > scaleH ? scaleW : scaleH;
                        scaleW = scaleH;
                        break;
                }
            }
        }
        return { width: scaleW, height: scaleH };
    };
    ImageCacheIt.prototype[common.headersProperty.getDefault] = function () {
        return new Map();
    };
    ImageCacheIt.prototype[common.headersProperty.setNative] = function (value) {
        var data = ImageCacheIt.cacheHeaders.get(this.uuid) || { url: undefined, headers: undefined };
        data['headers'] = value;
        ImageCacheIt.cacheHeaders.set(this.uuid, data);
    };
    ImageCacheIt.prototype._loadImage = function (src) {
        var _this = this;
        this._loadStarted = false;
        this._templateImageWasCreated = false;
        this.progress = 0;
        if (this.nativeView && this.nativeView.sd_cancelCurrentImageLoad) {
            this.nativeView.sd_cancelCurrentImageLoad();
        }
        var handleFileGif = function (file) {
            dispatch_async(filter_queue, function () {
                var data = NSData.dataWithContentsOfURL(NSURL.fileURLWithPath(file));
                var image = SDAnimatedImage.new().initWithData(data);
                dispatch_async(main_queue, function () {
                    _this._setupFilter(image);
                    _this.setTintColor(_this.style.tintColor);
                    _this._emitLoadEndEvent(src);
                    _this.progress = 100;
                });
            });
        };
        var handleResImage = function (name) {
            dispatch_async(filter_queue, function () {
                var image;
                var url = NSBundle.mainBundle.URLForResourceWithExtension(name, 'gif');
                if (url) {
                    var data = NSData.dataWithContentsOfURL(url);
                    if (data) {
                        image = SDAnimatedImage.alloc().initWithData(data);
                    }
                }
                if (!image) {
                    image = UIImage.imageNamed(name);
                }
                dispatch_async(main_queue, function () {
                    _this._setupFilter(image);
                    _this.setTintColor(_this.style.tintColor);
                    _this._emitLoadEndEvent(src);
                    _this.progress = 100;
                });
            });
        };
        if (!types.isNullOrUndefined(src)) {
            var ref_1 = new WeakRef(this);
            if (types.isString(src) && src.startsWith('http')) {
                var options = 1024 | 1 | 2048 | this._priority;
                this.isLoading = true;
                var context = {};
                var placeHolder = null;
                if (typeof this.placeHolder === 'string') {
                    var source = image_source_1.ImageSource.fromFileOrResourceSync(this.placeHolder);
                    placeHolder = source ? source.ios : null;
                }
                else if (this.placeHolder instanceof UIImage) {
                    placeHolder = this.placeHolder;
                }
                else if (this.placeHolder instanceof image_source_1.ImageSource) {
                    placeHolder = this.placeHolder.ios;
                }
                var url = NSURL.URLWithString(src);
                url.uuid = this.uuid;
                this.nativeView.sd_setImageWithURLPlaceholderImageOptionsContextProgressCompleted(url, placeHolder, options, context, function (p1, p2, p3) {
                    var owner = ref_1.get();
                    if (owner) {
                        dispatch_async(main_queue, function () {
                            if (!owner._loadStarted) {
                                owner._emitLoadStartEvent(p3.absoluteString);
                                owner._loadStarted = true;
                            }
                            var progress = 0;
                            if (p2 !== 0) {
                                progress = p1 / p2;
                            }
                            else {
                                progress = 1;
                            }
                            progress = Math.max(Math.min(progress, 1), 0) * 100;
                            owner.progress = progress;
                            owner._emitProgressEvent(p1, p2, progress, p3.absoluteString);
                        });
                    }
                }, function (p1, p2, p3, p4) {
                    var owner = ref_1.get();
                    if (owner) {
                        owner._templateImageWasCreated = true;
                        owner.isLoading = false;
                        if (owner.filter) {
                        }
                        if (p2) {
                            owner._emitErrorEvent(p2.localizedDescription, p4.absoluteString);
                            owner._emitLoadEndEvent(p4.absoluteString);
                            if (owner.errorHolder) {
                                var errorHolder = null;
                                if (typeof _this.errorHolder === 'string') {
                                    var source = image_source_1.ImageSource.fromFileOrResourceSync(_this.errorHolder);
                                    errorHolder = source ? source.ios : null;
                                }
                                else if (_this.errorHolder instanceof UIImage) {
                                    errorHolder = _this.errorHolder;
                                }
                                else if (_this.errorHolder instanceof image_source_1.ImageSource) {
                                    errorHolder = _this.errorHolder.ios;
                                }
                                owner.nativeView.image = errorHolder;
                                owner.setAspect(owner.stretch);
                                owner.setTintColor(owner.style.tintColor);
                            }
                        }
                        else if (p3 !== SDImageCacheType.Memory && owner.transition) {
                            switch (owner.transition) {
                                case 'fade':
                                    owner.nativeView.alpha = 0;
                                    UIView.animateWithDurationAnimations(1, function () {
                                        owner.nativeView.alpha = 1;
                                    });
                                    break;
                                default:
                                    break;
                            }
                        }
                        if (p1) {
                            if (owner.filter) {
                                dispatch_async(filter_queue, function () {
                                    owner._setupFilter(p1);
                                });
                            }
                            else {
                                dispatch_async(main_queue, function () {
                                    owner._setupFilter(p1);
                                });
                            }
                        }
                    }
                });
            }
            else if (typeof src === 'string' &&
                (src.startsWith('/') || src.startsWith('file'))) {
                this._emitLoadStartEvent(src);
                if (src.indexOf('.gif') > -1) {
                    handleFileGif(src);
                }
                else {
                    var source = image_source_1.ImageSource.fromFileOrResourceSync(src);
                    this._setupFilter(source ? source.ios : null);
                    this.setTintColor(this.style.tintColor);
                    this._emitLoadEndEvent(src);
                    this.progress = 100;
                }
            }
            else if (typeof src === 'string' &&
                src.startsWith('~')) {
                this._emitLoadStartEvent(src);
                var path = fs.knownFolders.currentApp().path;
                var file = fs.path.join(path, src.replace('~', ''));
                if (src.indexOf('.gif') > -1) {
                    handleFileGif(file);
                }
                else {
                    var source = image_source_1.ImageSource.fromFileOrResourceSync(file);
                    this._setupFilter(source ? source.ios : null);
                    this.setTintColor(this.style.tintColor);
                    this._emitLoadEndEvent(src);
                    this.progress = 100;
                }
            }
            else if (typeof src === 'string' && src.startsWith('res://')) {
                this._emitLoadStartEvent(src);
                handleResImage(src.replace('res://', ''));
            }
            else if (types.isObject(src) && src.ios) {
                this._emitLoadStartEvent(src);
                this._setupFilter(src.ios);
                this.setTintColor(this.style.tintColor);
                this._emitLoadEndEvent(src);
                this.progress = 100;
            }
            else if (types.isObject(src) && src instanceof UIImage) {
                this._emitLoadStartEvent(null);
                this._setupFilter(src);
                this.setTintColor(this.style.tintColor);
                this._emitLoadEndEvent(null);
                this.progress = 100;
            }
        }
        else {
            if (this.fallback) {
                this._loadImage(this.fallback);
            }
        }
    };
    ImageCacheIt.prototype.initNativeView = function () {
        _super.prototype.initNativeView.call(this);
        this._loadImage(this.src);
    };
    ImageCacheIt.prototype[common.srcProperty.getDefault] = function () {
        return undefined;
    };
    ImageCacheIt.prototype[common.srcProperty.setNative] = function (src) {
        var data = ImageCacheIt.cacheHeaders.get(this.uuid) || { url: undefined, headers: undefined };
        data['url'] = src;
        ImageCacheIt.cacheHeaders.set(this.uuid, data);
        this._loadImage(src);
    };
    ImageCacheIt.prototype[common.resizeProperty.setNative] = function (resize) {
        if (!this.nativeView)
            return resize;
        if (this.resize &&
            this.resize.split(',').length > 1) {
            this.nativeView.frame.size.width = parseInt(this.resize.split(' ')[0]);
            this.nativeView.frame.size.height = parseInt(this.resize.split(' ')[1]);
        }
        return resize;
    };
    ImageCacheIt.prototype.setAspect = function (value) {
        if (!this.nativeView)
            return value;
        switch (value) {
            case 'aspectFit':
                this.nativeView.contentMode = 1;
                break;
            case 'aspectFill':
                this.nativeView.contentMode = 2;
                break;
            case 'fill':
                this.nativeView.contentMode = 0;
                break;
            case 'none':
            default:
                this.nativeView.contentMode = 9;
                break;
        }
        return value;
    };
    ImageCacheIt.prototype[common.stretchProperty.getDefault] = function () {
        return 'aspectFit';
    };
    ImageCacheIt.prototype[common.stretchProperty.setNative] = function (value) {
        this.setAspect(value);
    };
    ImageCacheIt.prototype[common.filterProperty.setNative] = function (filter) {
        this.filter = filter;
        this._setupFilter(this.nativeView.image);
    };
    ImageCacheIt.prototype[common.tintColorProperty.setNative] = function (value) {
        this.setTintColor(value);
    };
    ImageCacheIt.prototype.setTintColor = function (value) {
        if (value && this.nativeViewProtected.image && !this._templateImageWasCreated) {
            this._templateImageWasCreated = true;
        }
        else if (!value && this.nativeViewProtected.image && this._templateImageWasCreated) {
            this._templateImageWasCreated = false;
        }
    };
    ImageCacheIt.prototype[common.priorityProperty.setNative] = function (value) {
        switch (value) {
            case image_cache_it_common_1.Priority.High:
                this._priority = 128;
                break;
            case image_cache_it_common_1.Priority.Low:
                this._priority = 2;
                break;
            default:
                this._priority = 0;
                break;
        }
    };
    ImageCacheIt.prototype._setupFilter = function (image) {
        var _this = this;
        var getValue = function (value) {
            return value.substring(value.indexOf('(') + 1, value.indexOf(')'));
        };
        var createFilterWithName = function (value) {
            var filter;
            if (!ImageCacheIt.ciFilterMap[value]) {
                ImageCacheIt.ciFilterMap[value] = CIFilter.filterWithName(value);
            }
            filter = ImageCacheIt.ciFilterMap[value];
            filter.setDefaults();
            if (image && image.CIImage) {
                filter.setValueForKey(image.CIImage, kCIInputImageKey);
                filter.setValueForKey(NSNull, kCIImageColorSpace);
            }
            else {
                if (image && image.CGImage) {
                    filter.setValueForKey(CIImage.imageWithCGImage(image.CGImage), kCIInputImageKey);
                }
            }
            return filter;
        };
        if (this.filter) {
            if (image) {
                var filters = this.filter ? this.filter.split(' ') : [];
                filters.forEach(function (filter) {
                    var value = getValue(filter);
                    if (filter.indexOf('blur') > -1) {
                        var width = -1;
                        if (value.indexOf('%') > -1) {
                            value = style_properties_1.Length.parse(value);
                            width = image.size.width * value;
                        }
                        else if (value.indexOf('px')) {
                            width = parseInt(value.replace('px', ''), 10);
                        }
                        else if (value.indexOf('dip')) {
                            width = parseInt(value.replace('dip', ''), 10) * platform.screen.mainScreen.scale;
                        }
                        else if (typeof value === 'number') {
                            width = value;
                        }
                        if (width > 25) {
                            width = 25;
                        }
                        if (width > -1) {
                            var blurFilter = createFilterWithName('CIGaussianBlur');
                            blurFilter.setValueForKey(width, kCIInputRadiusKey);
                            var blurredImg = blurFilter.valueForKey(kCIOutputImageKey);
                            if (blurredImg && blurredImg.extent) {
                                var cgiImage = _this.ctx.createCGImageFromRect(blurredImg, blurredImg.extent);
                                image = UIImage.imageWithCGImage(cgiImage);
                            }
                        }
                    }
                    else if (filter.indexOf('contrast') > -1) {
                        if (value.indexOf('%')) {
                            var contrast = parseFloat(value.replace('%', '')) / 100;
                            var contrastFilter = createFilterWithName('CIColorControls');
                            contrastFilter.setValueForKey(contrast, kCIInputContrastKey);
                            var contrastImg = contrastFilter.valueForKey(kCIOutputImageKey);
                            if (contrastImg && contrastImg.extent) {
                                var cgiImage = _this.ctx.createCGImageFromRect(contrastImg, contrastImg.extent);
                                image = UIImage.imageWithCGImage(cgiImage);
                            }
                        }
                    }
                    else if (filter.indexOf('brightness') > -1) {
                        if (value.indexOf('%')) {
                            var brightness = parseFloat(value.replace('%', '')) / 100;
                            var brightnessFilter = createFilterWithName('CIColorControls');
                            brightnessFilter.setValueForKey(brightness, kCIInputContrastKey);
                            var contrastImg = brightnessFilter.valueForKey(kCIOutputImageKey);
                            if (contrastImg && contrastImg.extent) {
                                var cgiImage = _this.ctx.createCGImageFromRect(contrastImg, contrastImg.extent);
                                image = UIImage.imageWithCGImage(cgiImage);
                            }
                        }
                    }
                    else if (filter.indexOf('grayscale') > -1 || filter.indexOf('greyscale') > -1) {
                        var grayscale = void 0;
                        if (value.indexOf('%') > -1) {
                            grayscale = parseFloat(value.replace('%', '')) / 100;
                        }
                        else if (value.indexOf('.') > -1) {
                            grayscale = parseFloat(value);
                        }
                        else {
                            grayscale = parseInt(value, 10);
                        }
                        if (grayscale > 1) {
                            grayscale = 1;
                        }
                        grayscale = 1 - grayscale;
                        var grayscaleFilter = createFilterWithName('CIColorControls');
                        grayscaleFilter.setValueForKey(grayscale, kCIInputSaturationKey);
                        var grayscaleImg = grayscaleFilter.valueForKey(kCIOutputImageKey);
                        if (grayscaleImg && grayscaleImg.extent) {
                            var cgiImage = _this.ctx.createCGImageFromRect(grayscaleImg, grayscaleImg.extent);
                            image = UIImage.imageWithCGImage(cgiImage);
                        }
                    }
                    else if (filter.indexOf('invert') > -1) {
                        var invertFilter = createFilterWithName('CIColorInvert');
                        var invertImg = invertFilter.valueForKey(kCIOutputImageKey);
                        if (invertImg && invertImg.extent) {
                            var cgiImage = _this.ctx.createCGImageFromRect(invertImg, invertImg.extent);
                            image = UIImage.imageWithCGImage(cgiImage);
                        }
                    }
                    else if (filter.indexOf('sepia') > -1) {
                        var sepia = parseFloat(value.replace('%', '')) / 100;
                        var sepiaFilter = createFilterWithName('CISepiaTone');
                        sepiaFilter.setValueForKey(sepia, kCIInputIntensityKey);
                        var sepiaImg = sepiaFilter.valueForKey(kCIOutputImageKey);
                        if (sepiaImg && sepiaImg.extent) {
                            var cgiImage = _this.ctx.createCGImageFromRect(sepiaImg, sepiaImg.extent);
                            image = UIImage.imageWithCGImage(cgiImage);
                        }
                    }
                    else if (filter.indexOf('opacity') > -1) {
                        var alpha = void 0;
                        if (value.indexOf('%') > -1) {
                            alpha = parseInt(value.replace('%', ''), 10) / 100;
                        }
                        else if (value.indexOf('.') > -1) {
                            alpha = parseFloat(value);
                        }
                        else {
                            alpha = parseInt(value, 10);
                        }
                        UIGraphicsBeginImageContextWithOptions(image.size, false, image.scale);
                        image.drawAtPointBlendModeAlpha(CGPointZero, 0, alpha);
                        image = UIGraphicsGetImageFromCurrentImageContext();
                        UIGraphicsEndImageContext();
                    }
                    else if (filter.indexOf('hue') > -1) {
                        var hueFilter = createFilterWithName('CIHueAdjust');
                        var hue = 0;
                        if (value.indexOf('deg') > -1) {
                            hue = parseInt(value.replace('deg', ''), 10);
                        }
                        else if (value.indexOf('turn') > -1) {
                            hue = parseInt(value.replace('turn', ''), 10) * 360;
                        }
                        hueFilter.setValueForKey(hue, kCIInputAngleKey);
                        var hueImg = hueFilter.valueForKey(kCIOutputImageKey);
                        if (hueImg && hueImg.extent) {
                            var cgiImage = _this.ctx.createCGImageFromRect(hueImg, hueImg.extent);
                            image = UIImage.imageWithCGImage(cgiImage);
                        }
                    }
                    else if (filter.indexOf('saturate') > -1) {
                        var saturateFilter = createFilterWithName('CIColorControls');
                        var saturate = void 0;
                        if (value.indexOf('%') > -1) {
                            saturate = parseInt(value.replace('%', ''), 10) / 100;
                        }
                        else if (value.indexOf('.') > -1) {
                            saturate = parseFloat(value);
                        }
                        else {
                            saturate = parseInt(value, 10);
                        }
                        saturateFilter.setValueForKey(saturate, kCIInputSaturationKey);
                        var saturateImg = saturateFilter.valueForKey(kCIOutputImageKey);
                        if (saturateImg && saturateImg.extent) {
                            var cgiImage = _this.ctx.createCGImageFromRect(saturateImg, saturateImg.extent);
                            image = UIImage.imageWithCGImage(cgiImage);
                        }
                    }
                });
            }
            dispatch_async(main_queue, function () {
                _this._emitLoadEndEvent(null, image);
                _this.setAspect(_this.stretch);
                _this.nativeView.image = image;
                _this.setTintColor(_this.style.tintColor);
            });
        }
        else {
            dispatch_async(main_queue, function () {
                _this._emitLoadEndEvent(null, image);
                _this.setAspect(_this.stretch);
                _this.nativeView.image = image;
                _this.setTintColor(_this.style.tintColor);
            });
        }
    };
    ImageCacheIt.hasItem = function (src) {
        return new Promise(function (resolve, reject) {
            var manager = SDWebImageManager.sharedManager;
            if (manager) {
                var key = manager.cacheKeyForURL(NSURL.URLWithString(src));
                manager.imageCache.containsImageForKeyCacheTypeCompletion(key, 3, function (type) {
                    if (type > 0) {
                        resolve();
                    }
                    else {
                        reject();
                    }
                });
            }
            else {
                reject();
            }
        });
    };
    ImageCacheIt.deleteItem = function (src) {
        return new Promise(function (resolve, reject) {
            var manager = SDWebImageManager.sharedManager;
            if (manager) {
                var key = manager.cacheKeyForURL(NSURL.URLWithString(src));
                manager.imageCache.removeImageForKeyFromDiskWithCompletion(key, true, function () {
                    resolve();
                });
            }
            else {
                reject();
            }
        });
    };
    ImageCacheIt.clear = function () {
        return new Promise(function (resolve, reject) {
            var manager = SDWebImageManager.sharedManager;
            if (manager) {
                manager.imageCache.clearMemory();
                manager.imageCache.clearDiskOnCompletion(function () {
                    resolve();
                });
            }
        });
    };
    ImageCacheIt.enableAutoMM = function () {
        ImageCacheIt.autoMMCallback = function (args) {
            var manager = SDWebImageManager.sharedManager;
            if (manager) {
                manager.imageCache.clearMemory();
            }
        };
        app.on(app.lowMemoryEvent, ImageCacheIt.autoMMCallback);
    };
    ImageCacheIt.disableAutoMM = function () {
        if (ImageCacheIt.autoMMCallback) {
            app.off(app.lowMemoryEvent, ImageCacheIt.autoMMCallback);
        }
    };
    ImageCacheIt.getItem = function (src) {
        return new Promise(function (resolve, reject) {
            var manager = SDWebImageManager.sharedManager;
            if (manager) {
                if (src && src.indexOf('http') > -1) {
                    var nativeSrc = NSURL.URLWithString(src);
                    manager.loadImageWithURLOptionsProgressCompleted(nativeSrc, SDWebImageOptions.scaleDownLargeImages, function (receivedSize, expectedSize, path) {
                    }, function (image, data, error, type, finished, completedUrl) {
                        if (image === null && error !== null && data === null) {
                            reject(error.localizedDescription);
                        }
                        else if (finished && completedUrl != null) {
                            if (type === SDImageCacheType.disk) {
                                var key = manager.cacheKeyForURL(completedUrl);
                                var source = manager.imageCache.cachePathForKey(key);
                                resolve(source);
                            }
                            else {
                                var sharedCache = SDImageCache.sharedImageCache;
                                sharedCache.storeImageForKeyCompletion(image, completedUrl.absoluteString, function () {
                                    var key = manager.cacheKeyForURL(completedUrl);
                                    var source = manager.imageCache.cachePathForKey(key);
                                    resolve(source);
                                });
                            }
                        }
                    });
                }
            }
            else {
                reject();
            }
        });
    };
    ImageCacheIt.cacheHeaders = new Map();
    ImageCacheIt.hasModifier = false;
    ImageCacheIt.ciFilterMap = {};
    return ImageCacheIt;
}(image_cache_it_common_1.ImageCacheItBase));
exports.ImageCacheIt = ImageCacheIt;
//# sourceMappingURL=image-cache-it.ios.js.map